@@ -1,6 +1,6 @@
 """ Lumino DataGrid widgets powered by pandas and JSON Table Schema
 """
-from ._version import __version__  # noqa
+from ._version import __version__, module_name
 from .widget_datagrid import DataGrid
 from .widget_selectgrid import SelectGrid
 from .widget_stylegrid import (
@@ -23,3 +23,7 @@ __all__ = [
     "StyleGrid",
     "TextRenderer",
 ]
+
+
+def _jupyter_labextension_paths():
+    return [{"src": "labextension", "dest": module_name}]
